#[non_exhaustive]pub enum AtmosphereModel {
Standard(Ussa76),
Sounding(Box<SoundingProfile>),
}Expand description
Any of the atmosphere models, tagged by model when serialized.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Standard(Ussa76)
Ussa76, optionally offset.
Sounding(Box<SoundingProfile>)
SoundingProfile, boxed because it is far larger than the standard.