pub struct AirSample {
pub air: AirState,
pub extrapolated: Option<Side>,
}Expand description
An AirState and whether the model extrapolated beyond its data or its defined range to
produce it.
Fields
air: AirStateThe air at the requested height.
extrapolated: Option<Side>Some when the height was below or above the range the model is defined or tabulated
over; None inside it, ends included.