pub struct AirState {
pub temperature_k: f64,
pub pressure_pa: f64,
pub density_kg_m3: f64,
pub speed_of_sound_m_s: f64,
pub dynamic_viscosity_pa_s: f64,
}Expand description
Thermodynamic and transport properties of the air at one point.
Fields
temperature_k: f64Kinetic temperature T, K.
pressure_pa: f64Static pressure p, Pa.
density_kg_m3: f64Density ρ, kg/m³ (of the moist air, where a model carries humidity).
speed_of_sound_m_s: f64Speed of sound a, m/s.
dynamic_viscosity_pa_s: f64Dynamic viscosity μ, Pa·s.
Implementations