pub struct WindSample {
pub velocity_enu_m_s: DVec3,
pub extrapolated: Option<Side>,
}Expand description
A wind velocity and whether the model extrapolated to produce it.
Fields
velocity_enu_m_s: DVec3Velocity of the air in East-North-Up axes, m/s.
extrapolated: Option<Side>Some when the height was below or above a tabulated wind’s levels, or below ground for
a law written above ground; None otherwise. The power and log laws are not flagged above
the surface layer they describe.